package com.yijia.integral.mapper;

import java.util.List;
import com.yijia.integral.domain.CustomerPointsRecord;

/**
 * 客户积分记录Mapper接口
 * 
 * @author yijia
 * @date 2021-03-17
 */
public interface CustomerPointsRecordMapper 
{
    /**
     * 查询客户积分记录
     * 
     * @param id 客户积分记录ID
     * @return 客户积分记录
     */
    public CustomerPointsRecord selectCustomerPointsRecordById(Long id);

    /**
     * 查询客户积分记录列表
     * 
     * @param customerPointsRecord 客户积分记录
     * @return 客户积分记录集合
     */
    public List<CustomerPointsRecord> selectCustomerPointsRecordList(CustomerPointsRecord customerPointsRecord);

    /**
     * 新增客户积分记录
     * 
     * @param customerPointsRecord 客户积分记录
     * @return 结果
     */
    public int insertCustomerPointsRecord(CustomerPointsRecord customerPointsRecord);

    /**
     * 修改客户积分记录
     * 
     * @param customerPointsRecord 客户积分记录
     * @return 结果
     */
    public int updateCustomerPointsRecord(CustomerPointsRecord customerPointsRecord);

    /**
     * 删除客户积分记录
     * 
     * @param id 客户积分记录ID
     * @return 结果
     */
    public int deleteCustomerPointsRecordById(Long id);

    /**
     * 批量删除客户积分记录
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteCustomerPointsRecordByIds(Long[] ids);
}
