package com.yijia.integral.controller;

import java.util.List;

import com.yijia.common.core.domain.entity.SysDept;
import com.yijia.common.core.domain.model.LoginUser;
import com.yijia.common.utils.SecurityUtils;
import com.yijia.system.service.ISysDeptService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yijia.common.annotation.Log;
import com.yijia.common.core.controller.BaseController;
import com.yijia.common.core.domain.AjaxResult;
import com.yijia.common.enums.BusinessType;
import com.yijia.integral.domain.CustomerPointsRecord;
import com.yijia.integral.service.ICustomerPointsRecordService;
import com.yijia.common.utils.poi.ExcelUtil;
import com.yijia.common.core.page.TableDataInfo;

/**
 * 客户积分记录Controller
 *
 * @author yijia
 * @date 2021-03-17
 */
@RestController
@RequestMapping("/integral/record")
public class CustomerPointsRecordController extends BaseController
{
    @Autowired
    private ICustomerPointsRecordService customerPointsRecordService;
    @Autowired
    private ISysDeptService deptService;
    /**
     * 查询客户积分记录列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CustomerPointsRecord customerPointsRecord)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        SysDept dept =new SysDept();
        dept.setDeptId(currentUser.getUser().getDeptId());
        List<String> list = deptService.selectDeptId(dept);
        if(list!=null && list.size()>0){
            customerPointsRecord.setStationIdList(list);
            customerPointsRecord.setStationId(null);
        }
        startPage();
        List<CustomerPointsRecord> recordList = customerPointsRecordService.selectCustomerPointsRecordList(customerPointsRecord);
        return getDataTable(recordList);
    }

    /**
     * 导出客户积分记录列表
     */
    @Log(title = "客户积分记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(CustomerPointsRecord customerPointsRecord)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        SysDept dept =new SysDept();
        dept.setDeptId(currentUser.getUser().getDeptId());
        List<String> list = deptService.selectDeptId(dept);
        if(list!=null && list.size()>0){
            customerPointsRecord.setStationIdList(list);
            customerPointsRecord.setStationId(null);
        }
        List<CustomerPointsRecord> recordList = customerPointsRecordService.selectCustomerPointsRecordList(customerPointsRecord);
        ExcelUtil<CustomerPointsRecord> util = new ExcelUtil<CustomerPointsRecord>(CustomerPointsRecord.class);
        return util.exportExcel(recordList, "record");
    }

    /**
     * 获取客户积分记录详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(customerPointsRecordService.selectCustomerPointsRecordById(id));
    }

    /**
     * 新增客户积分记录
     */
    @Log(title = "客户积分记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CustomerPointsRecord customerPointsRecord)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        customerPointsRecord.setStationId(currentUser.getUser().getDeptId());
        customerPointsRecord.setStationName(currentUser.getUser().getDept().getDeptName());
        return toAjax(customerPointsRecordService.insertCustomerPointsRecord(customerPointsRecord));
    }

    /**
     * 修改客户积分记录
     */
    @Log(title = "客户积分记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CustomerPointsRecord customerPointsRecord)
    {
        LoginUser currentUser = SecurityUtils.getLoginUser();
        customerPointsRecord.setStationId(currentUser.getUser().getDeptId());
        customerPointsRecord.setStationName(currentUser.getUser().getDept().getDeptName());
        return toAjax(customerPointsRecordService.updateCustomerPointsRecord(customerPointsRecord));
    }

    /**
     * 删除客户积分记录
     */
    @Log(title = "客户积分记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(customerPointsRecordService.deleteCustomerPointsRecordByIds(ids));
    }
}
